@@ -45,10 +45,7 @@ class Stopwatch:
 def sec_to_str(seconds) -> str:
     if not isinstance(seconds, int):
         return "00:00:00"
-    return (
-        f"{seconds // 3600}".zfill(2)
-        + ":"
-        + f"{seconds % 3600 // 60}".zfill(2)
-        + ":"
-        + f"{seconds % 60}".zfill(2)
-    )
+    time = f"{seconds % 3600 // 60}:".zfill(3) + f"{seconds % 60}".zfill(2)
+    if seconds // 3600:
+        time = f"{seconds // 3600}:{time}"
+    return time
