@@ -4,29 +4,22 @@ from textual.reactive import watch
 from textual.views._grid_view import GridView
 
 from .. import db
+from ..config import config
+from ..events import Upd
+from ..stopwatch import sec_to_str
 from ..widgets.current_task import CurrentTask
 from ..widgets.header import MyHeader
 from ..widgets.in_app_logger import ialogger
 from ..widgets.simple_scrollview import SimpleScrollView
 from ..widgets.tasklist import TaskList
 from ..widgets.timer import Timer
-from ..widgets.total import Total
 
 
 class MainView(GridView):
     def __init__(self, name: str | None = "MainView") -> None:
         super().__init__(name=name)
         self._init_widgets()
-
-    async def on_mount(self) -> None:
         self._make_grid()
-        self._place_widgets()
-        watch(self.timer, "_working", self.set_blocked)
-        watch(self.tasklist, "current_task", self.start_task)
-        watch(self.tasklist, "upd_total", self.update_total)
-
-    async def update_total(self, _) -> None:
-        self.total.refresh()
 
     def _init_widgets(self) -> None:
         self.header = MyHeader()
@@ -35,16 +28,21 @@ class MainView(GridView):
         self.ialogger = ialogger
         self.tasklist = TaskList()
         self.t_scroll = SimpleScrollView(self.tasklist)
-        self.total = Total(self.tasklist.root.data)
 
     def _make_grid(self) -> None:
         self.grid.add_column("left", fraction=1)
-        self.grid.add_column("right", fraction=3)
+        self.grid.add_column("right", min_size=50, fraction=3)
         self.grid.add_row("header", fraction=1, size=1)
         self.grid.add_row("r1", fraction=1, size=3)
         self.grid.add_row("r2", fraction=1, size=3)
         self.grid.add_row("r3", fraction=1)
-        self.grid.add_row("r4", fraction=1, size=1)
+
+    async def on_focus(self) -> None:
+        await self.tasklist.focus()
+
+    def on_mount(self) -> None:
+        self._place_widgets()
+        watch(self.tasklist, "current_task", self.start_task)
 
     def _place_widgets(self) -> None:
         self.grid.add_areas(
@@ -53,7 +51,6 @@ class MainView(GridView):
             focus="left,r2",
             logger="left,r3",
             timelist="right,header-end|r3-end",
-            total="left-start|right-end, r4",
         )
         self.grid.place(
             header=self.header,
@@ -61,12 +58,8 @@ class MainView(GridView):
             focus=self.timer,
             logger=self.ialogger,
             timelist=self.t_scroll,
-            total=self.total,
         )
 
-    async def set_blocked(self, working) -> None:
-        self.tasklist.blocked = working
-
     async def start_task(self, current_task) -> None:
         if not current_task:
             self.current_task.clear_content()
@@ -75,10 +68,7 @@ class MainView(GridView):
             self.switch_timer()
 
     def set_current_task(self, current_task) -> None:
-        if current_task:
-            self.current_task._content = current_task.name
-        else:
-            self.current_task.clear_content()
+        self.current_task._content = current_task.title
 
     def switch_timer(self) -> None:
         if not self.tasklist.current_task:
@@ -90,19 +80,24 @@ class MainView(GridView):
             ialogger.update("Running")
         self.timer.switch_timer()
 
-    def save_session(self) -> None:
+    async def save_session(self) -> None:
         if self.save_data() and self.tasklist.current_task:
             self.tasklist.add_time(self.timer.time)
-            self.total.refresh()
-        self.timer.restart_timer()
+        hl = config.styles["LOGGER_HIGHLIGHT"]
+        ialogger.update(
+            "[b]Session saved[/]\n"
+            f"[{hl}]{self.current_task.content}[/] - "
+            f"{sec_to_str(self.timer.time)}"
+        )
         self.tasklist.current_task = None
-        ialogger.update("Session saved. Timer reset.")
+        self.timer.restart_timer()
+        await self.app.post_message_from_child(Upd(self))
 
     def save_data(self) -> bool:
         if not (self.timer.time and self.tasklist.current_task):
             return False
         db.add_session(
-            self.tasklist.current_task.task_id,
+            self.tasklist.current_task.id,
             datetime.now().strftime("%Y-%m-%d"),
             self.timer.time,
         )
